;; Generated package description from buttercup.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "buttercup" "1.40.0.20260512.214133" "Behavior-Driven Emacs Lisp Testing" '((emacs "24.4")) :commit "39c8e762408a166a5afa03b8e79dd8d1a0de5caa" :authors '(("Jorgen Schaefer" . "contact@jorgenschaefer.de")) :maintainer '("Ola Nilsson" . "ola.nilsson@gmail.com") :url "https://github.com/jorgenschaefer/emacs-buttercup")
